@@ -24,8 +24,7 @@
 
 class QListWidgetItem;
 
-namespace Ui
-{
+namespace Ui {
 class SelectProgramPage;
 }
 
