@@ -18,30 +18,16 @@
 */
 #include "importwizard.h"
 #include "importwizardkernel.h"
-#include "selectprogrampage.h"
-#include "selectcomponentpage.h"
-#include "importmailpage.h"
-#include "importfilterpage.h"
-#include "importsettingpage.h"
-#include "importaddressbookpage.h"
-#include "importcalendarpage.h"
-#include "importfinishpage.h"
-
-#include "autodetect/thunderbird/thunderbirdimportdata.h"
-#include "autodetect/sylpheed/sylpheedimportdata.h"
-#include "autodetect/evolutionv3/evolutionv3importdata.h"
-#include "autodetect/evolutionv2/evolutionv2importdata.h"
-#include "autodetect/evolutionv1/evolutionv1importdata.h"
-#include "autodetect/icedove/icedoveimportdata.h"
-#include "autodetect/opera/operaimportdata.h"
-#include "autodetect/oe/oeimportdata.h"
-#include "autodetect/mailapp/mailappimportdata.h"
-#include "autodetect/pmail/pmailimportdata.h"
-#include "autodetect/thebat/thebatimportdata.h"
-#include "autodetect/balsa/balsaimportdata.h"
-#include "autodetect/claws-mail/clawsmailimportdata.h"
-#include "autodetect/trojita/trojitaimportdata.h"
-#include "autodetect/geary/gearyimportdata.h"
+#include "autodetect/selectprogrampage.h"
+#include "autodetect/selectcomponentpage.h"
+#include "autodetect/importmailpage.h"
+#include "autodetect/importfilterpage.h"
+#include "autodetect/importsettingpage.h"
+#include "autodetect/importaddressbookpage.h"
+#include "autodetect/importcalendarpage.h"
+#include "autodetect/importfinishpage.h"
+#include "importmailpluginmanager.h"
+#include "importwizarddisplayinfo.h"
 
 #include "manual/manualimportmailpage.h"
 #include "manual/manualselectfilterpage.h"
@@ -61,13 +47,14 @@
 #include <QPushButton>
 
 ImportWizard::ImportWizard(WizardMode mode, QWidget *parent)
-    : KAssistantDialog(parent),
-      mMode(mode),
-      mSelectedPim(nullptr)
+    : KAssistantDialog(parent)
+    , mMode(mode)
+    , mSelectedPim(nullptr)
 {
     setModal(true);
     setWindowTitle(i18n("PIM Import Tool"));
     setStandardButtons(QDialogButtonBox::Cancel | QDialogButtonBox::Help);
+    mAbstractDisplayInfo = new ImportWizardDisplayInfo(this);
 
     ImportWizardKernel *kernel = new ImportWizardKernel(this);
     CommonKernel->registerKernelIf(kernel);   //register KernelIf early, it is used by the Filter classes
@@ -92,7 +79,7 @@ ImportWizard::ImportWizard(WizardMode mode, QWidget *parent)
     resize(640, 480);
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
 
-    if (mode == AutoDetect) {
+    if (mode == WizardMode::AutoDetect) {
         checkModules();
         KMessageBox::information(this, i18n("Close KMail before importing data. Some plugins will modify KMail config file."));
     }
@@ -107,7 +94,6 @@ ImportWizard::ImportWizard(WizardMode mode, QWidget *parent)
 
 ImportWizard::~ImportWizard()
 {
-    qDeleteAll(mlistImport);
     writeConfig();
 }
 
@@ -128,7 +114,7 @@ void ImportWizard::writeConfig()
 
 void ImportWizard::updatePagesFromMode()
 {
-    const bool autodetectMode = (mMode == AutoDetect);
+    const bool autodetectMode = (mMode == WizardMode::AutoDetect);
     setAppropriate(mSelectProgramPageItem, autodetectMode);
     setAppropriate(mSelectComponentPageItem, autodetectMode);
     setAppropriate(mImportMailPageItem, autodetectMode);
@@ -219,30 +205,13 @@ void ImportWizard::createAutomaticModePage()
 
 void ImportWizard::initializeImportModule()
 {
-    //Import module
-    addImportModule(new ThunderbirdImportData(this));
-    addImportModule(new IcedoveImportData(this));
-    addImportModule(new SylpheedImportData(this));
-    addImportModule(new Evolutionv3ImportData(this));
-    addImportModule(new Evolutionv2ImportData(this));
-    addImportModule(new Evolutionv1ImportData(this));
-    addImportModule(new OperaImportData(this));
-#ifdef Q_OS_WIN
-    addImportModule(new OeImportData(this));
-#endif
-#ifdef Q_OS_MAC
-    addImportModule(new MailAppImportData(this));
-#endif
-
-#ifdef Q_OS_WIN
-    addImportModule(new PMailImportData(this));
-    addImportModule(new TheBatImportData(this));
-#endif
-
-    addImportModule(new BalsaImportData(this));
-    addImportModule(new ClawsMailImportData(this));
-    addImportModule(new TrojitaImportData(this));
-    addImportModule(new GearyImportData(this));
+    const QVector<LibImportWizard::AbstractImporter *> lstPlugins = ImportMailPluginManager::self()->pluginsList();
+    for (LibImportWizard::AbstractImporter *abstractPlugin : qAsConst(lstPlugins)) {
+        if (abstractPlugin->foundMailer()) {
+            abstractPlugin->setAbstractDisplayInfo(mAbstractDisplayInfo);
+            mlistImport.insert(abstractPlugin->name(), abstractPlugin);
+        }
+    }
 }
 
 void ImportWizard::slotProgramDoubleClicked()
@@ -292,7 +261,7 @@ void ImportWizard::slotImportCalendarClicked()
 
 void ImportWizard::slotProgramSelected(const QString &program)
 {
-    AbstractImporter *importer = mlistImport.value(program);
+    LibImportWizard::AbstractImporter *importer = mlistImport.value(program);
     if (importer) {
         mSelectedPim = importer;
         setValid(currentPage(), true);
@@ -304,7 +273,7 @@ void ImportWizard::checkModules()
     mSelectProgramPage->setFoundProgram(mlistImport.keys());
 }
 
-void ImportWizard::addImportModule(AbstractImporter *import)
+void ImportWizard::addImportModule(LibImportWizard::AbstractImporter *import)
 {
     if (import->foundMailer()) {
         mlistImport.insert(import->name(), import);
@@ -318,13 +287,13 @@ void ImportWizard::slotAtLeastOneComponentSelected(bool result)
     setValid(mSelectComponentPageItem, result);
 }
 
-void ImportWizard::setAppropriatePage(AbstractImporter::TypeSupportedOptions options)
+void ImportWizard::setAppropriatePage(LibImportWizard::AbstractImporter::TypeSupportedOptions options)
 {
-    setAppropriate(mImportMailPageItem, (options & AbstractImporter::Mails));
-    setAppropriate(mImportFilterPageItem, (options & AbstractImporter::Filters));
-    setAppropriate(mImportSettingPageItem, (options & AbstractImporter::Settings));
-    setAppropriate(mImportAddressbookPageItem, (options & AbstractImporter::AddressBooks));
-    setAppropriate(mImportCalendarPageItem, (options & AbstractImporter::Calendars));
+    setAppropriate(mImportMailPageItem, (options & LibImportWizard::AbstractImporter::Mails));
+    setAppropriate(mImportFilterPageItem, (options & LibImportWizard::AbstractImporter::Filters));
+    setAppropriate(mImportSettingPageItem, (options & LibImportWizard::AbstractImporter::Settings));
+    setAppropriate(mImportAddressbookPageItem, (options & LibImportWizard::AbstractImporter::AddressBooks));
+    setAppropriate(mImportCalendarPageItem, (options & LibImportWizard::AbstractImporter::Calendars));
 }
 
 void ImportWizard::next()
@@ -407,11 +376,11 @@ void ImportWizard::back()
 {
     if (currentPage() == mSelectProgramPageItem) {
         return;
-    } else if (currentPage() == mImportFilterPageItem ||
-               currentPage() == mImportSettingPageItem ||
-               currentPage() == mImportAddressbookPageItem ||
-               currentPage() == mImportCalendarPageItem ||
-               currentPage() == mImportFinishPageItem) {
+    } else if (currentPage() == mImportFilterPageItem
+               || currentPage() == mImportSettingPageItem
+               || currentPage() == mImportAddressbookPageItem
+               || currentPage() == mImportCalendarPageItem
+               || currentPage() == mImportFinishPageItem) {
         enableAllImportButton();
     }
     KAssistantDialog::back();
@@ -459,6 +428,6 @@ void ImportWizard::addFinishError(const QString &log)
 
 void ImportWizard::slotSelectManualSelectionChanged(bool b)
 {
-    mMode = b ? Manual : AutoDetect;
+    mMode = b ? WizardMode::Manual : WizardMode::AutoDetect;
     updatePagesFromMode();
 }
